import { ref } from 'vue'
import { ElMessage, ElLoading } from 'element-plus'
import { saveAs } from 'file-saver'
import request from '@/axios'
import { blobValidate } from '@/utils/downUtils'
import {
  ADD_WIDTH_INTERFACE_URL,
  EDIT_WIDTH_INTERFACE_URL,
  FIELD_INTERFACE_URL,
  SAVE_FIELD_INTERFACE_URL,
  UPDATE_FIELD_INTERFACE_URL,
  WIDTH_INTERFACE_URL
} from '@/constants'

// 获取菜单
export const getRoutersApi = (params: any): Promise<IResponse> => {
  return request.get({ url: '/system/management/menu/getRouters', params })
}
// 获取全部部门
export const getAllDeptListApi = (params: any): Promise<IResponse> => {
  return request.get({ url: '/system/management/dept/getAll', params })
}

// 根据查询条件查询部门列表
export const getDeptListByLevelApi = async (data: any): Promise<IResponse> => {
  return request.post({ url: '/system/management/dept/getDeptList', data })
}

// 根据查询条件查询部门下拉列表
export const getDeptListByParentIdApi = async (params: any): Promise<IResponse> => {
  return request.get({ url: '/system/management/dept/selectDepts', params })
}

// 查询所有线路与lineCode
export const getAllLineListApi = async (params: any): Promise<IResponse> => {
  return request.get({ url: '/system-center/management/lineInfo/listAll', params })
}

// 查询所有线路名称
export const getAllLineNameListApi = async (params: any): Promise<IResponse> => {
  return request.get({ url: '/system-center/management/lineInfo/lineNameList', params })
}
// 获取所有管界中的线路信息
export const getBoundLineInfoApi = async (params: any): Promise<IResponse> => {
  return request.get({ url: '/system-center/tManageBoundInfo/getBoundLineInfo', params })
}
// 根据部门id查询线路与行别信息
export const getLineAndBussByDeptIdApi = async (params: any): Promise<IResponse> => {
  return request.get({ url: '/system-center/tManageBoundInfo/getLineAndBussByDeptId', params })
}

// 根据线名lineCode查询行别列表
export const getLineBussByLineCodeApi = async (params: any): Promise<IResponse> => {
  return request.get({ url: '/system-center/management/lineInfo/getLineBussByLineCode', params })
}

// 根据模块标识查询列宽数据
export const getWidthByFlagApi = async (params: any, type = 1): Promise<IResponse> => {
  return request.get({ url: WIDTH_INTERFACE_URL[type], params })
}
// 自定义宽度-新增
export const saveWidthApi = (data: any, type = 1): Promise<IResponse> => {
  return request.post({ url: ADD_WIDTH_INTERFACE_URL[type], data })
}

// 自定义宽度-修改
export const editWidthApi = (data: any, type = 1): Promise<IResponse> => {
  return request.put({ url: EDIT_WIDTH_INTERFACE_URL[type], data })
}

// 根据模块名与用户ID自定义查询、表格
export const getTableFilterApi = async (data: any, type = 1): Promise<IResponse> => {
  return request.post({ url: FIELD_INTERFACE_URL[type], data })
}
// 自定义查询、表格-新增
export const saveTableFilterApi = (data: any, type = 1): Promise<IResponse> => {
  return request.post({ url: SAVE_FIELD_INTERFACE_URL[type], data })
}
// 自定义查询、表格-修改
export const editTableFilterApi = (data: any, type = 1): Promise<IResponse> => {
  return request.put({ url: UPDATE_FIELD_INTERFACE_URL[type], data })
}

let downloadLoadingInstance: any
// 下载数据格式化
export const downloadInit = (res, oldFilename, isOldName?) => {
  const disposition = res.headers['content-disposition']
  const stringName = disposition ? disposition.split('filename=')[1] : '' // 一般来说，文件名字后端都在返回头里，前后端可以约定文件名前用 @ 符号分隔，便于取值，用其他符号也可以。
  let fileNameType = stringName ? stringName.split('.')[1] : '' // 获取到了后缀名

  const typeIndex = stringName.lastIndexOf('.')
  let name = stringName // 获取到文件名
  if (typeIndex > -1) {
    fileNameType = stringName.substring(typeIndex + 1, stringName.length) // 获取到了后缀名
    name = stringName.substring(0, typeIndex) // 获取到文件名（不含后缀）
  }
  // decodeURIComponent(name) ,一般来说后端返回的名字没有转码，需要前端解码utf-8，如果后端转了，就不用转。
  const fileName = name ? `${decodeURIComponent(name)}.${fileNameType}` : ''

  const isBlob = blobValidate(res)
  if (isBlob) {
    const blob = new Blob([res.data])
    if (isOldName) {
      saveAs(blob, oldFilename)
    } else {
      saveAs(blob, fileName || oldFilename)
    }
  }
  downloadLoadingInstance.close()
}
// 通用下载方法-post
export const download = async (
  url: string,
  params: any,
  filename: string,
  isJson = false,
  isParam = false
) => {
  downloadLoadingInstance = ElLoading.service({
    text: '正在下载数据，请稍候',
    background: 'rgba(0, 0, 0, 0.7)'
  })

  const data = { ...params }
  Object.keys(data).map((key) => {
    if (Array.isArray(data[key])) {
      data[key] = data[key].join(',')
    }
  })
  if (!isParam) {
    params = {}
  }
  return request
    .post({
      url,
      data,
      params,
      headers: {
        'Content-Type': isJson ? 'application/json' : 'application/x-www-form-urlencoded'
      },
      responseType: 'blob'
    })
    .then(async (res) => {
      downloadInit(res, filename)
    })
    .catch(() => {
      // ElMessage.error('下载文件出现错误，请联系管理员！')
      downloadLoadingInstance.close()
    })
}

// get方法下载
export const downloadGet = async (url: string, params: any, filename: string) => {
  downloadLoadingInstance = ElLoading.service({
    text: '正在下载数据，请稍候',
    background: 'rgba(0, 0, 0, 0.7)'
  })
  return request
    .get({
      url,
      headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      responseType: 'blob',
      params: params
    })
    .then(async (res) => {
      downloadInit(res, filename)
    })
    .catch(() => {
      ElMessage.error('下载文件出现错误，请联系管理员！')
      downloadLoadingInstance.close()
    })
}

// 通用附件下载 trans是否转换文件格式
export const downloadFileCommon = async (
  url: string,
  params: any,
  filename: string,
  trans?: boolean
) => {
  downloadLoadingInstance = ElLoading.service({
    text: '正在下载数据，请稍候',
    background: 'rgba(0, 0, 0, 0.7)'
  })
  const list = url.split('.')
  const type = list[list.length - 1]
  const name = filename.indexOf('.') > -1 ? filename : `${filename}.${type}`
  const transPdf = ref<boolean>(false)
  if (trans) {
    transPdf.value = type === 'doc' || type === 'docx'
  } else {
    transPdf.value = false
  }
  if (transPdf.value) {
    let Pdfurl = ''
    Pdfurl = url.split('/statics')[1]
    return request
      .post({
        responseType: 'blob',
        url: '/api/mgdaas-file/management/downloadPdf?' + 'filePath=' + Pdfurl,
        params: params
      })
      .then((res) => {
        const newName = filename.split('.')[0] + '.pdf'
        downloadInit(res, newName, true)
      })
  } else {
    return request
      .get({
        url: url,
        responseType: 'blob',
        params: params
      })
      .then((res) => {
        const isBlob = blobValidate(res)
        if (isBlob) {
          const blob = new Blob([res.data])
          saveAs(blob, name)
        }
        downloadLoadingInstance.close()
      })
      .catch(() => {
        ElMessage.error('下载文件出现错误，请联系管理员！')
        downloadLoadingInstance.close()
      })
  }
}
let uploadLoadingInstance: any
// 通用导入方法
export const uploldFile = async (url: string, params: any, uploadParams?: any) => {
  uploadLoadingInstance = ElLoading.service({
    text: '正在上传数据，请稍候',
    background: 'rgba(0, 0, 0, 0.7)'
  })
  const formData = new FormData()
  formData.append('file', params.file)
  if (uploadParams) {
    Object.keys(uploadParams).map((key) => {
      formData.append(key, uploadParams[key])
    })
  }
  const data = formData
  return new Promise((resolve) => {
    return request
      .post({
        url,
        data,
        headers: {
          'Content-Type': 'multipart/form-data'
        }
      })
      .then(async (data) => {
        resolve(data)
        uploadLoadingInstance.close()
      })
      .catch((r) => {
        resolve(r)
        // ElMessage.error('导入文件出现错误，请联系管理员！')
        uploadLoadingInstance.close()
      })
  })
}
