// 部门
export interface DepartmentItem {
  id: string
  departmentName: string
  children?: DepartmentItem[]
}

export interface DepartmentListResponse {
  list: DepartmentItem[]
}

export interface DepartmentUserParams {
  pageSize: number
  pageIndex: number
  id: string
  username?: string
  account?: string
}

export interface DepartmentUserItem {
  id: string
  username: string
  account: string
  email: string
  createTime: string
  role: string
  department: DepartmentItem
}

export interface DepartmentUserResponse {
  rows: DepartmentUserItem[]
  total: number
}

// 用户管理 -- type
export type UserData = {
  userId: undefined | number | string
  createBy: string // 创建人
  createTime: string // 创建时间
  email: string | null // 邮箱
  mailbox: null
  updateBy: string // 修改人
  updateTime: string // 修改时间
  deptName: string // 部门名称
  deptId: number | null // 部门id
  remark: string // 备注
  posts: number[] | string[] // 岗位
  roles: number[] | string[] // 角色
  roleIds: any //
  postIds: any //
  postId: any
  roleId: number | string // 角色id
  roleName: string // 角色名称
  roleKey: string
  roleSort: number | null
  dataScope: string
  phonenumber: string | null // 手机号码
  menuCheckStrictly: boolean
  deptCheckStrictly: boolean
  status: string // 状态
  sex: string // 性别
  delFlag: string
  flag: boolean
  menuIds: number[]
  deptIds: number[]
  permissions: string
  admin: boolean
  password: string
  user: null
}

export type DeptTreeData = {
  id: string
  label: string
  children: DeptTreeData[]
}

export type DeptUserTreeData = {
  checkedKeys: number[]
  menus: DeptTreeData[]
}
// 岗位
export type PostData = {
  createBy: string
  createTime: string
  updateBy: string
  updateTime: string
  remark: string
  postId: string
  postCode: string
  postName: string
  postSort: number | null
  status: string
  flag: boolean
}
// 字典
export type DictData = {
  createBy: string
  createTime: string
  updateBy: string
  updateTime: string
  remark: string
  dictId: string
  dictName: string
  dictType: string
  status: string
}

export type DictTypeData = {
  createBy: string
  createTime: string
  cssClass: string
  default: string
  dictCode: string
  dictLabel: string
  dictSort: string
  dictType: string
  dictValue: string
  isDefault: string
  listClass: string
  remark: string
  status: string
  updateBy: string
  updateTime: string
}

export type DictOptionData = {
  elTagClass: string
  elTagType: string
  label: string
  value: string
}
// 角色
export type RoleData = {
  createBy: string
  createTime: string
  updateBy: string
  updateTime: string
  remark: string
  roleId: string
  roleName: string
  roleKey: string
  roleSort: number | null
  dataScope: string
  menuCheckStrictly: boolean
  deptCheckStrictly: boolean
  status: string
  delFlag: string
  flag: boolean
  menuIds: any
  deptIds: number[]
  permissions: string
  admin: boolean
}

export type DeptRoleTreeData = {
  checkedKeys: number[]
  menus: DeptTreeData[]
}

export type AuthUserData = {
  admin: boolean
  avatar: string
  createBy: string
  createTime: string
  delFlag: string
  dept: []
  deptId: string
  email: string
  ldapUserId: string
  loginDate: string
  loginIp: string
  nickName: string
  password: string
  phonenumber: string
  postIds: string
  remark: string
  roleId: string
  roleIds: string
  roles: []
  sex: string
  status: string
  updateBy: string
  updateTime: string
  userId: string
  userName: string
}
// 菜单
export type MenuData = {
  createBy: string
  createTime: string
  updateBy: string
  updateTime: string
  remark: string
  menuId: string
  menuName: string
  parentName: string
  parentId: number
  orderNum: number | null
  path: string
  component: string
  query: string
  isFrame: string
  isCache: string
  menuType: string
  visible: string
  status: string
  perms: string
  icon: string | null
  parentIds: number[]
  children: MenuData[]
}

export type MenuTreeData = {
  id: string
  label: string
  children: MenuTreeData[]
}

export type MenuRoleTreeData = {
  checkedKeys: number[]
  menus: MenuTreeData[]
}
