import request from '@/axios'
import type { UserData, DeptTreeData } from './types'
import { download } from '../common'

export const getUserInfoApi = (params: any): Promise<IResponse> => {
  return request.get({ url: '/system/management/user/getInfo', params })
}

// 获取用户数据列表(分页)
export const getUserListApi = (params: any): Promise<IResponse> => {
  return request.get({ url: '/system/management/user/list', params })
}

export const saveDataApi = (data: Partial<UserData>, isEdit = false): Promise<IResponse> => {
  if (isEdit) {
    return request.put({ url: '/system/management/user', data })
  } else {
    return request.post({ url: '/system/management/user', data })
  }
}

// 新增
export const saveUserApi = (data: Partial<UserData>): Promise<IResponse> => {
  return request.post({ url: '/system/management/user', data })
}

// 修改
export const editUserApi = (data: Partial<UserData>): Promise<IResponse> => {
  return request.put({ url: '/system/management/user', data })
}
// 删除
export const delUserListApi = (ids: string): Promise<IResponse> => {
  return request.delete({ url: '/system/management/user/' + ids })
}
// 根据id获取用户信息
export const getUserDetailApi = (id: string | number | undefined): Promise<IResponse<UserData>> => {
  return request.get({ url: '/system/management/user/' + id })
}
// 新增获取岗位和角色
export const getUserSelectApi = (params: any): Promise<IResponse<UserData>> => {
  return request.get({ url: '/system/management/user/', params })
}

// 根据用户id获取分配角色信息
export const getAuthRoleInfoApi = (id: number | string): Promise<IResponse<UserData>> => {
  return request.get({ url: '/system/management/user/authRole/' + id })
}
// 根据用户id保存分配角色信息
export const getSubmitAuthRoleInfoApi = (data: Partial<UserData>): Promise<IResponse> => {
  return request.put({
    url: '/system/management/user/authRole',
    data,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  })
}
// 批量调整部门
export const batchChangeDeptApi = (data: any): Promise<IResponse> => {
  return request.post({
    url: '/system/management/user/updateDepts',
    params: data
  })
}

// 修改用户状态
export const chageUserStatusApi = (data: Partial<UserData>): Promise<IResponse> => {
  return request.put({ url: '/system/management/user/changeStatus', data })
}
// 重置密码
export const resetPassWord = (data: Partial<UserData>): Promise<IResponse> => {
  return request.put({ url: '/system/management/user/resetPwd', data })
}
//批量 重置密码
export const batchResetPassWord = (data: Partial<UserData>): Promise<IResponse> => {
  return request.put({ url: '/system/management/user/resetPwds', data })
}
export const dataScopeApi = (data: Partial<UserData>): Promise<IResponse> => {
  return request.put({ url: '/system/management/role/dataScope', data })
}

// 获取部门树
export const getUserDeptListApi = (params: any): Promise<IResponse<DeptTreeData>> => {
  return request.get({ url: '/system/management/user/deptTree', params })
}

export const exportUserListApi = (data: any) => {
  return download('/system/management/user/export', data, `user_${new Date().getTime()}.xlsx`)
}
