import { AxiosResponse, InternalAxiosRequestConfig } from './types'
import { ElMessage, ElMessageBox, ElScrollbar } from 'element-plus'
import qs from 'qs'
import { SUCCESS_CODE, TRANSFORM_REQUEST_DATA } from '@/constants'
import { useUserStoreWithOut } from '@/store/modules/user'
import { objToFormData } from '@/utils'
import { h } from 'vue'
// import { useRouter } from 'vue-router'
import router from '@/router'
import { useCache } from '@/hooks/web/useCache'
import { useCookies } from 'vue3-cookies'

const { cookies } = useCookies()
// const router = useRouter()
const defaultRequestInterceptors = (config: InternalAxiosRequestConfig) => {
  if (
    config.method === 'post' &&
    config.headers['Content-Type'] === 'application/x-www-form-urlencoded'
  ) {
    config.data = qs.stringify(config.data)
  } else if (
    TRANSFORM_REQUEST_DATA &&
    config.method === 'post' &&
    config.headers['Content-Type'] === 'multipart/form-data' &&
    !(config.data instanceof FormData)
  ) {
    config.data = objToFormData(config.data)
  }
  if (config.method === 'get' && config.params) {
    let url = config.url as string
    url += '?'
    const keys = Object.keys(config.params)
    for (const key of keys) {
      if (config.params[key] !== void 0 && config.params[key] !== null) {
        url += `${key}=${encodeURIComponent(config.params[key])}&`
      }
    }
    url = url.substring(0, url.length - 1)
    config.params = {}
    config.url = url
  }
  return config
}
const { wsCache } = useCache()
const defaultResponseInterceptors = (response: AxiosResponse) => {
  if (response?.config?.responseType === 'blob') {
    if (response.data.type == 'application/json') {
      //转换步骤
      const file: any = new FileReader()
      file.readAsText(response.data, 'utf-8')
      let data: any = {}
      file.onload = function () {
        data = JSON.parse(file.result)
        if (data.code !== SUCCESS_CODE) {
          ElMessage.error(data.tip || data.message || '下载失败！')
          // return Promise.reject(data)
          return
        }
        return data
      }
    } else {
      // 如果是文件流，直接过
      return response
    }
  } else if (response.data) {
    if (response.data.code === SUCCESS_CODE) {
      return response.data
    }

    const data = response.data
    const userStore = useUserStoreWithOut()
    let tips = ''
    switch (data.code) {
      case '400':
        ElMessage.error(data.tip || data.message || '参数异常')
        break
      case '401':
        ElMessage({
          message: data.tip || data.message || '用户无权限，请联系系统管理员！',
          type: 'error',
          duration: 2000,
          grouping: true
        })
        // ElMessage.error(data.tip || data.message || '用户无权限，请联系系统管理员！')
        wsCache.clear()

        localStorage.clear()
        cookies.remove('')

        userStore.reset()
        router?.replace({
          path: '/login'
        })
        break
      case '402':
        ElMessage.error(data.tip || data.message || '用户未登录，请重新登录！')
        break
      case '403':
        ElMessage.error(data.tip || data.message || '用户无权限')
        break
      case '500':
        ElMessage.error(data.tip || data.message || '服务器内部错误，请联系系统管理员！')
        break
      case '100400':
        ElMessage.error(data.tip || data.message || 'token错误，请重新登录！')
        break
      case '100401':
        ElMessage.error(data.tip || data.message || '用户不存在，请联系管理员！')
        break
      case '100402':
        ElMessage.error(data.tip || data.message || '有导入失败项！')
        break
      case 'A0406':
        tips = data.tip || data.message || '有导入失败项！'
        // ElMessage.closeAll()
        if (tips.length < 1000) {
          setTimeout(() => {
            ElMessage({
              showClose: true,
              message: tips,
              type: 'error',
              duration: 0,
              grouping: true
            })
          }, 0)
        } else {
          ElMessageBox({
            title: '提示',
            message: h(
              ElScrollbar,
              {
                style: {
                  height: '80vh',
                  overflow: 'hidden'
                }
              },
              [
                h(
                  'div',
                  {
                    style: {
                      height: '100%',
                      overflowY: 'scroll'
                    }
                  },
                  tips
                )
              ]
            ),
            customClass: 'import-tip'
          })
        }
        break
      case 'A0201':
        ElMessage.error(data.tip || data.message || '用户名不存在/密码错误')
        break
      default:
        if (data.tip || data.message) {
          ElMessage({
            message: data.tip || data.message,
            type: 'error',
            duration: 2000,
            grouping: true
          })
          // ElMessage.error(data.tip || data.message)
        } else {
          ElMessage.error('服务请求失败, 内部系统异常！')
        }

        break
    }
  } else {
    ElMessage.error(response?.data?.message)
    if (response?.data?.code === 401) {
      const userStore = useUserStoreWithOut()
      userStore.logout()
    }
  }
}

export { defaultResponseInterceptors, defaultRequestInterceptors }
