import { ElSubMenu, ElMenuItem } from 'element-plus'
import { ComputedRef, unref } from 'vue'
import { hasOneShowingChild } from '../helper'
import { isUrl } from '@/utils/is'
import { useRenderMenuTitle } from './useRenderMenuTitle'
import { pathResolve } from '@/utils/routerHelper'
import { useAppStore } from '@/store/modules/app'
import { getFirstUrl } from '@/utils'

import { useDesign } from '@/hooks/web/useDesign'

const { getPrefixCls } = useDesign()
const prefixCls = getPrefixCls('submenu')

const { renderMenuTitle } = useRenderMenuTitle()
export const useRenderMenuItem = (
  isFirstMenuTop: boolean,
  menuMode?: ComputedRef<'vertical' | 'horizontal'>
) =>
  // allRouters: AppRouteRecordRaw[] = [],
  {
    const appStore = useAppStore()
    const renderMenuItem = (routers: AppRouteRecordRaw[], parentPath = '/') => {
      if (!routers) {
        return
      }
      return routers
        .filter((v) => !v.meta?.hidden)
        .map((v) => {
          const meta = v.meta ?? {}
          const { oneShowingChild, onlyOneChild } = hasOneShowingChild(v.children, v)
          const fullPath = isUrl(v.path) ? v.path : pathResolve(parentPath, v.path) // getAllParentPath<AppRouteRecordRaw>(allRouters, v.path).join('/')
          if (isFirstMenuTop && meta?.alwaysShow) {
            return (
              <ElMenuItem
                index={v.children?.length ? v.path : fullPath}
                onClick={() => {
                  if (!v.children || v.children.length === 0) {
                    v.children = [v]
                  }
                  const url = getFirstUrl(v.children, '')
                  appStore.setSubMenuList(v.children)
                  appStore.setCurrentActivedPath(v.path)
                  appStore.setFirstActivedPath(url)
                }}
              >
                {{
                  default: () => renderMenuTitle(v ? v?.meta : meta)
                }}
              </ElMenuItem>
            )
          } else {
            if (
              isUrl(v.path) ||
              v.link ||
              v.menuType === 'C' ||
              ((!v.children || v.children.length === 0 || !v.name) && !meta?.alwaysShow)
            ) {
              return (
                <ElMenuItem
                  index={onlyOneChild ? pathResolve(fullPath, onlyOneChild.path) : fullPath}
                >
                  {{
                    default: () => renderMenuTitle(onlyOneChild ? onlyOneChild?.meta : meta, true)
                  }}
                </ElMenuItem>
              )
            } else {
              return (
                <ElSubMenu index={fullPath}>
                  {{
                    title: () => renderMenuTitle(meta),
                    default: () => renderMenuItem(v.children!, fullPath)
                  }}
                </ElSubMenu>
              )
            }
          }
        })
    }

    return {
      renderMenuItem
    }
  }
