import useDictStore from '@/store/modules/appDict'
import { getDictsApi } from '@/api/sys/dict'
import { ref, toRefs } from 'vue'

/**
 * 获取字典数据
 */
export const useDict = (...args: any[]) => {
  const res = ref({})
  return (() => {
    args.forEach((dictType, _index) => {
      res.value[dictType] = []
      const dicts = useDictStore().getDict(dictType)
      if (dicts) {
        res.value[dictType] = dicts
      } else {
        getDictsApi(dictType).then((resp) => {
          res.value[dictType] = resp?.data?.map((p) => ({
            label: p.dictLabel,
            value: p.dictValue,
            elTagType: p.listClass,
            elTagClass: p.cssClass
          }))
          useDictStore().setDict(dictType, res.value[dictType])
        })
      }
    })
    return toRefs(res.value)
  })()
}
/**
 * 获取字典数据
 */
export const useDictLabel = (...args: any[]) => {
  const res = ref({})
  return (() => {
    args.forEach((dictType, _index) => {
      res.value[dictType] = []
      const dicts: any = useDictStore().getDict(dictType)
      if (dicts) {
        dicts.map((item: any) => {
          res.value[dictType].push({
            ...item,
            value: item.label,
            keyValue: item.keyValue || item.value
          })
        })
        // res.value[dictType] = dicts
      } else {
        getDictsApi(dictType).then((resp) => {
          res.value[dictType] = []
          resp.data.map((p) => {
            res.value[dictType].push({
              label: p.dictLabel,
              value: p.dictLabel,
              keyValue: p.dictValue,
              elTagType: p.listClass,
              elTagClass: p.cssClass
            })
          })

          useDictStore().setDict(dictType, res.value[dictType])
        })
      }
    })
    return toRefs(res.value)
  })()
}

/**
 * 根据当前值获取当前字典数据
 */
export const getDictLabel = (value: string | number, list: any) => {
  const result = ref()
  list.value?.forEach((item, _index) => {
    if (item.value === value) {
      result.value = {
        ...item
      }
    }
  })
  return result.value
}
